@@ -121,7 +121,7 @@ class DewPoint:
         T = flx.IQ_interpolation(f, Tmin, Tmax,
                                  f(Tmin, *args), f(Tmax, *args),
                                  None, 1e-9, 5e-12, args,
-                                 checkroot=False, checkbounds=False)
+                                 checkiter=False, checkbounds=False)
         return T
     
     def _P_ideal(self, z_over_Psats):
@@ -175,14 +175,14 @@ class DewPoint:
         try:
             T = flx.aitken_secant(f, T_guess, T_guess + 1e-3,
                                   1e-9, 5e-12, args,
-                                  checkroot=False)
+                                  checkiter=False)
         except (InfeasibleRegion, DomainError):
             Tmin = self.Tmin
             Tmax = self.Tmax
             T = flx.IQ_interpolation(f, Tmin, Tmax,
                                      f(Tmin, *args), f(Tmax, *args),
                                      T_guess, 1e-9, 5e-12, args,
-                                     checkroot=False, checkbounds=False)
+                                     checkiter=False, checkbounds=False)
         self.x = fn.normalize(self.x)
         return T, self.x.copy()
     
@@ -224,14 +224,14 @@ class DewPoint:
         P_guess = self.P or self._P_ideal(z_over_Psats)
         try:
             P = flx.aitken_secant(f, P_guess, P_guess-10, 1e-3, 5e-12, args,
-                                  checkroot=False)
+                                  checkiter=False)
         except (InfeasibleRegion, DomainError):
             Pmin = self.Pmin
             Pmax = self.Pmax
             P = flx.IQ_interpolation(f, Pmin, Pmax, 
                                      f(Pmin, *args), f(Pmax, *args),
                                      P_guess, 1e-3, 5e-12, args,
-                                     checkroot=False, checkbounds=False)
+                                     checkiter=False, checkbounds=False)
         self.x = fn.normalize(self.x)
         return P, self.x.copy()
     
